#!/bin/bash

##############################################################################
#
# MODULE:       r.avaflow.install.sh
#
# AUTHOR:       Martin Mergili
#
# PURPOSE:      The open source GIS simulation model
#               for granular avalanches and debris flows
#               Installation script
#
# COPYRIGHT:    (c) 2010 - 2016 by the author
#               (c) 2010 - 2016 by the BOKU University, Vienna
#               (c) 2015 - 2016 by the University of Vienna
#               (c) 2000 - 2016 by the GRASS Development Team
#
# VERSION:      20160720 (20 July 2016)
#
#               This program is free software under the GNU General Public
#               License (>=v2). Read the file COPYING that comes with GRASS
#               for details.
#
##############################################################################


pathmain=`pwd`

PATHSOURCE="/usr/local/src/releasebranch_7_0/"
PATHGRASS="/usr/local/grass-7.0.2svn/"
PATHPYTHON="/usr/lib/python2.7/"

#echo "Full path to GRASS source (slashes at beginning and end): "
#read PATHSOURCE

#echo "Full path to GRASS installation (slashes at beginning and end): "
#read PATHGRASS

#echo "Full path to Python installation (slashes at beginning and end): "
#read PATHPYTHON


#INSTALLING R- AND PYTHON-BASED MODULES FOR DATA MANAGEMENT
#Exporting parameters
export GISBASE="$PATHGRASS"
export PATH="$PATH:$GISBASE/bin:$GISBASE/scripts"
export LD_LIBRARY_PATH="$LD_LIBRARY_PATH:$GISBASE/lib"
export GIS_LOCK=$$
export GISRC="$HOME/.grassrc6"
export PYTHONPATH="$PYTHONPATH:$GISBASE/etc/python"

#Installing R scripts and Python library
cp r.avaflow.hydrograph.r "$PATHGRASS"scripts/r.avaflow.hydrograph.r
cp r.avaflow.map.r "$PATHGRASS"scripts/r.avaflow.map.r
cp r.avaflow.profile.r "$PATHGRASS"scripts/r.avaflow.profile.r
cp r.avaflow.roc.r "$PATHGRASS"scripts/r.avaflow.roc.r
cp images2gif.py "$PATHPYTHON"images2gif.py

#r.avaflow.py is installed as a module r.avaflow
#Making python script executable
chmod +x r.avaflow.py

#Removing directory with installation files, if existing
if [ -d "$PATHSOURCE"scripts/r.avaflow ]
then
    rm -rf "$PATHSOURCE"scripts/r.avaflow
fi

#Creating directory for installation files, copying r.avaflow.py and r.avaflow.html
mkdir "$PATHSOURCE"scripts/r.avaflow
cp r.avaflow.py "$PATHSOURCE"scripts/r.avaflow/r.avaflow.py
cp r.avaflow.html "$PATHSOURCE"scripts/r.avaflow/r.avaflow.html

#Moving to the directory for installation files
cd "$PATHSOURCE"scripts/r.avaflow

# Creating help file and makefile
touch r.avaflow.html
echo "MODULE_TOPDIR = ../.." > Makefile
echo "" >> Makefile
echo "PGM = r.avaflow" >> Makefile
echo "" >> Makefile
echo "include \$(MODULE_TOPDIR)/include/Make/Script.make" >> Makefile
echo "" >> Makefile
echo "default: script" >> Makefile

#Installing r.avaflow
make
make install

cd $pathmain

#r.avaflow.mult.py is installed as module r.avaflow.mult
#Making python script executable
chmod +x r.avaflow.mult.py

#Removing directory with installation files, if existing
if [ -d "$PATHSOURCE"scripts/r.avaflow.mult ]
then
    rm -rf "$PATHSOURCE"scripts/r.avaflow.mult
fi

#Creating directory for installation files, copying r.avaflow.mult.py
mkdir "$PATHSOURCE"scripts/r.avaflow.mult
cp r.avaflow.mult.py "$PATHSOURCE"scripts/r.avaflow.mult/r.avaflow.mult.py
cp r.avaflow.html "$PATHSOURCE"scripts/r.avaflow.mult/r.avaflow.mult.html

#Moving to the directory for installation files
cd "$PATHSOURCE"scripts/r.avaflow.mult

# Creating help file and makefile
touch r.avaflow.mult.html
echo "MODULE_TOPDIR = ../.." > Makefile
echo "" >> Makefile
echo "PGM = r.avaflow.mult" >> Makefile
echo "" >> Makefile
echo "include \$(MODULE_TOPDIR)/include/Make/Script.make" >> Makefile
echo "" >> Makefile
echo "default: script" >> Makefile

#Installing r.avaflow.mult
make
make install

echo ""
echo "Installation of r.avaflow, r.avaflow.mult and associated scripts completed. Please check for possible error messages. "
echo "Press ENTER for proceeding with the installation of r.avaflow.main. "
read answer

#Returning to initial directory
cd $pathmain
clear


#INSTALLING C-BASED MODULE FOR FLOW ROUTING
#r.avaflow.main.c is installed as module r.avaflow.main
#Removing directory with installation files, if existing
if [ -d "$PATHSOURCE"raster/r.avaflow.main ]
then
    rm -rf "$PATHSOURCE"raster/r.avaflow.main
fi

#Creating directory for installation files and copying r.avaflow.main.c
mkdir "$PATHSOURCE"raster/r.avaflow.main
cp r.avaflow.main.c "$PATHSOURCE"raster/r.avaflow.main/main.c
cp r.avaflow.html "$PATHSOURCE"dist.x86_64-unknown-linux-gnu/docs/html/r.avaflow.main.html

#Moving to the directory for installation files
cd "$PATHSOURCE"raster/r.avaflow.main

# Creating makefile
echo "MODULE_TOPDIR = ../.." > Makefile
echo "" >> Makefile
echo "PGM = r.avaflow.main" >> Makefile
echo "" >> Makefile
echo "LIBES = \$(GPROJDEP) \$(GISLIB) \$(SEGMENTLIB) \$(RASTERLIB) \$(GMATHLIB)" >> Makefile
echo "DEPENDENCIES = \$(GPROJDEP) \$(GISDEP) \$(GMATHDEP)" >> Makefile
echo "EXTRA_INC = \$(PROJINC)" >> Makefile
echo "" >> Makefile
echo "include \$(MODULE_TOPDIR)/include/Make/Module.make" >> Makefile
echo "" >> Makefile
echo "default: cmd" >> Makefile

# Installing r.avaflow.main
make
make install

echo ""
echo "Installation of r.avaflow.main completed. Please check for possible error messages. "
echo "Press ENTER for exit. "
read answer

#Returning to initial directory and terminating sudo mode
cd $pathmain
sudo -k
clear
